@@ -26,6 +26,8 @@ class TestZeeman:
         Ms = 1e6
 
         system = mm.System(name=name)
+
+        # time-independent
         system.energy = mm.Zeeman(H=H)
 
         mesh = df.Mesh(region=self.region, cell=self.cell)
@@ -37,6 +39,24 @@ class TestZeeman:
         value = system.m(mesh.region.random_point())
         assert np.linalg.norm(np.subtract(value, (0, 0, Ms))) < 1e-3
 
+        # time-dependent - sine
+        system.energy = mm.Zeeman(H=H, wave='sin', f=1e9, t0=1e-12)
+
+        mesh = df.Mesh(region=self.region, cell=self.cell)
+        system.m = df.Field(mesh, dim=3, value=(1, 1, 1), norm=Ms)
+
+        td = self.calculator.TimeDriver()
+        td.drive(system, t=0.1e-9, n=20)
+
+        # time-dependent - sinc
+        system.energy = mm.Zeeman(H=H, wave='sinc', f=1e9, t0=0)
+
+        mesh = df.Mesh(region=self.region, cell=self.cell)
+        system.m = df.Field(mesh, dim=3, value=(1, 1, 1), norm=Ms)
+
+        td = self.calculator.TimeDriver()
+        td.drive(system, t=0.1e-9, n=20)
+
         self.calculator.delete(system)
 
     def test_dict(self):
